==> material__dialog-1.0.0-0.jar: META-INF/resources/webjars/material__dialog/1.0.0-0/util.d.ts <==
/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import * as createFocusTrap from 'focus-trap';
export declare type MDCDialogFocusTrapFactory = (element: HTMLElement | string, userOptions?: createFocusTrap.Options) => createFocusTrap.FocusTrap;
export declare function createFocusTrapInstance(surfaceEl: HTMLElement, focusTrapFactory?: MDCDialogFocusTrapFactory, initialFocusEl?: createFocusTrap.FocusTarget): createFocusTrap.FocusTrap;
export declare function isScrollable(el: HTMLElement | null): boolean;
export declare function areTopsMisaligned(els: HTMLElement[]): boolean;

==> material__dialog-1.1.1.jar: META-INF/resources/webjars/material__dialog/1.1.1/util.d.ts <==
/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { FocusTarget, FocusTrap, Options } from 'focus-trap';
export declare type MDCDialogFocusTrapFactory = (element: HTMLElement | string, userOptions?: Options) => FocusTrap;
export declare function createFocusTrapInstance(surfaceEl: HTMLElement, focusTrapFactory?: MDCDialogFocusTrapFactory, initialFocusEl?: FocusTarget): FocusTrap;
export declare function isScrollable(el: HTMLElement | null): boolean;
export declare function areTopsMisaligned(els: HTMLElement[]): boolean;
